==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/sh/sections.php <==
<?php
regGS("Section List", "Lista rubrika");
regGS("Section #$1 \"$2\" updated. (Publication: $3, Issue: $4)", "Rubrika #$1 \"$2\" je izmenjena. (publikacija:  $3, izdanje:  $4)");
regGS("Go To Articles", "Idi na članke");
regGS("Add section to all subscriptions.", "Dodaj rubriku u sve pretplate.");
regGS("Delete section from all subscriptions.", "Obriši rubriku iz svih pretplata.");
regGS("A total of $1 subscriptions were updated.", "Ukupan broj izmenjenih pretplata: $1.");
regGS("Name<BR><SMALL>(click to see articles)</SMALL>", "Naziv<br><small>(kliknite za pregled članaka)</small>");
regGS("Delete section $1", "Obriši rubriku");
regGS("Adding new section", "Dodavanje nove rubrike");
regGS("You do not have the right to add sections.", "Nemate pravo da dodajete rubrike");
regGS("The section $1 has been successfuly added.", "Rubrika $1 je uspešno dodata");
regGS("Please check if another section with the same number or URL name does not exist already.", "Proverite da li druga rubrika sa istim brojem ili URL imenom već ne postoji.");
regGS("Select the section", "Izaberite rubriku");
regGS("Delete section", "Obriši rubriku");
regGS("You do not have the right to delete sections.", "Nemate pravo da brišete rubrike.");
regGS("Are you sure you want to delete the section $1?", "Da li ste sigurni da želite da obrišete rubriku $1?");
regGS("Deleting section", "Brisanje rubrika");
regGS("The section $1 has been deleted.", "Rubrika $1 je obrisana");
regGS("Configure section", "Podesi rubriku");
regGS("Updating section name", "Menjanje imena rubrike");
regGS("The section could not be changed.", "Rubrika ne može biti izmenjena.");
regGS("Name<BR><SMALL>(click to add article)</SMALL>", "Ime<br><small> (kliknite da dodate članak)</small>");
regGS("Duplicate section", "Dupliraj rubriku");
regGS("The destination issue is the same as the source issue.", "Ciljno izdanje je isto kao matično.");
regGS("Error updating subscriptions.", "Greška pri promeni pretplata.");
regGS("Duplicating section", "Dupliranje rubrike");
regGS("The section $1 could not be duplicated", "Rubrika $1 ne može biti duplirana ");
regGS("Section $1 has been duplicated to $2. $3 of $4", "Rubrika $1 je duplirana u $2. $3 od $4");
regGS("You do not have the right to modify sections.", "Nemate pravo da menjate rubrike.");
regGS("Delete all articles from the section.", "Obriši sve članke iz rubrike.");
regGS("A total of $1 articles were deleted.", "Ukupno je obrisano $1 članak(a).");
regGS("Duplicate Section:", "Dupliraj rubriku:");
regGS("Existing Section", "Postojeća rubrika");
regGS("Go to new section", "Idi u novu rubriku");
regGS("Go to source section", "Idi u početnu rubriku");
regGS("New Section", "Nova rubrika");
regGS("Please select either '$1' or '$2'.", "Izaberite '$1' ili '$2'.");
regGS("Select destination section:", "Izaberite ciljnu rubriku");
regGS("OR", "ILI");
regGS("URL Name", "URL ime");
regGS("The section number specified already exists, please specify a different value or use the dropdown to find an existing section.", "Navedeni broj rubrike već postoji, izaberite drugu vrednost ili koristite padajući meni za izbor postojeće rubrike.");
regGS("Warning", "Upozorenje");
regGS("You must select a section.", "Morate izabrati rubriku");
regGS("You must specify a name for the section.", "Morate uneti ime rubrike.");
regGS("Please check if another section with the same number does not already exist.", "Proverite da li već ne postoji rubrika pod istim brojem");
regGS("Short Name", "Skraćeno ime");
regGS("Destination section number", "Broj ciljne rubrike");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/sh/sections.php <==
<?php
regGS("The URL name must be unique for all sections in this issue.<br>The URL name you specified (\"$1\") conflicts with section \"$2$3. $4$5\"", "");
regGS("Section updated", "");
regGS("There are $1 subscriptions which will be affected.", "");
regGS("There are $1 articles in this section.", "");
regGS("Section #$1 \"$2\" updated. (Publication: $3, Issue: $4)", "Rubrika #$1 \"$2\" je izmenjena. (publikacija:  $3, izdanje:  $4)");
regGS("Go To Articles", "Idi na tekstove");
regGS("Add section to all subscriptions.", "Dodaj rubriku u sve pretplate.");
regGS("Delete section from all subscriptions.", "Obriši rubriku iz svih pretplata.");
regGS("A total of $1 subscriptions were updated.", "Ukupan broj izmenjenih pretplata: $1.");
regGS("Name<BR><SMALL>(click to see articles)</SMALL>", "Naziv<br><small>(kliknite listing tekstova)</small>");
regGS("Delete section $1", "Obriši rubriku");
regGS("Adding new section", "Dodavanje nove rubrike");
regGS("You do not have the right to add sections.", "Nemate pravo da dodajete rubrike");
regGS("The section $1 has been successfuly added.", "Rubrika $1 je uspešno dodata");
regGS("Please check if another section with the same number or URL name does not exist already.", "Proverite da li druga rubrika sa istim brojem ili URL imenom već ne postoji.");
regGS("Delete section", "Obriši rubriku");
regGS("You do not have the right to delete sections.", "Nemate pravo da brišete rubrike.");
regGS("Are you sure you want to delete the section $1?", "Da li ste sigurni da želite da obrišete rubriku $1?");
regGS("Deleting section", "Brisanje rubrika");
regGS("The section $1 has been deleted.", "Rubrika $1 je obrisana");
regGS("Configure section", "Podesi rubriku");
regGS("The section could not be changed.", "Rubrika ne može biti izmenjena.");
regGS("Duplicate section", "Dupliraj rubriku");
regGS("The destination issue is the same as the source issue.", "Ciljno izdanje je isto kao matično.");
regGS("Error updating subscriptions.", "Greška pri promeni pretplata.");
regGS("Duplicating section", "Dupliranje rubrike");
regGS("The section $1 could not be duplicated", "Rubrika $1 ne može biti duplirana ");
regGS("Section $1 has been duplicated to $2. $3 of $4", "Rubrika $1 je duplirana u $2. $3 od $4");
regGS("You do not have the right to modify sections.", "Nemate pravo da menjate rubrike.");
regGS("A total of $1 articles were deleted.", "Ukupno je obrisano $1 tekst(ova).");
regGS("Duplicate Section:", "Dupliraj rubriku:");
regGS("Existing Section", "Postojeća rubrika");
regGS("Go to new section", "Idi u novu rubriku");
regGS("Go to source section", "Idi u početnu rubriku");
regGS("New Section", "Nova rubrika");
regGS("Please select either '$1' or '$2'.", "Izaberite '$1' ili '$2'.");
regGS("Select destination section:", "Izaberite ciljnu rubriku");
regGS("OR", "ILI");
regGS("URL Name", "URL ime");
regGS("The section number specified already exists, please specify a different value or use the dropdown to find an existing section.", "Navedeni broj rubrike već postoji, izaberite drugu vrednost ili koristite padajući meni za izbor postojeće rubrike.");
regGS("Warning", "Upozorenje");
regGS("You must select a section.", "Morate izabrati rubriku");
regGS("You must specify a name for the section.", "Morate uneti ime rubrike.");
regGS("Please check if another section with the same number does not already exist.", "Proverite da li već ne postoji rubrika pod istim brojem");
regGS("Short Name", "Skraćeno ime");
regGS("Destination section number", "Broj ciljne rubrike");
regGS("The section could not be added.", "Rubrika ne može biti dodata.");
regGS("Add new section", "Dodaj novu rubriku");
?>
